# Guides

This section contains guides and tutorials for using Pykka.

- [Logging](logging.md) - learn how to configure logging in Pykka.
- [Unit testing](testing.md) - learn how to test code that uses Pykka.
- [Deadlock debugging](deadlocks.md) - learn how to debug deadlocks in Pykka
  applications.
- [Proxy typing](proxy-typing.md) - learn how to add type hints for actor proxies.
